@@ -6,7 +6,7 @@ var operator_position = {
   sanity: [
     'var res = a + b - c / d * e % f;',
     'var res = g & h | i ^ j |> console.log;',
-    'var res = (k && l || m) ? n : o;',
+    'var res = (k && l || m) ? n ?? nn : o;',
     'var res = p >> q << r >>> s;',
     'var res = t === u !== v != w == x >= y <= z > aa < ab;',
     'ac + -ad'
@@ -25,6 +25,7 @@ var operator_position = {
     'l',
     '|| m) ?',
     'n',
+    '?? nn',
     ': o',
     ';',
     'var res = p',
